@@ -943,7 +943,7 @@ int main(int argc, char *argv[])
 	GtkWidget 	*main_box;
 	GtkWidget 	*hbox;
 	GtkWidget 	*qm;
-	GtkWidget 	*quit;
+	//GtkWidget 	*quit;
 	GtkWidget 	*label;
 	GtkWidget 	*sw;
 	GtkWidget 	*abox;
@@ -1089,7 +1089,6 @@ int main(int argc, char *argv[])
 	g_signal_connect ( G_OBJECT(del_button), "clicked", G_CALLBACK(rem_bookmarks), NULL);
 	g_signal_connect ( G_OBJECT(mnt_button), "clicked", G_CALLBACK(load_bookmarks), NULL);
 	g_signal_connect ( G_OBJECT(umnt_button), "clicked", G_CALLBACK(unload_bookmarks), NULL);
-	g_signal_connect ( G_OBJECT(quit), "clicked", G_CALLBACK(gtk_main_quit), NULL);
 	g_signal_connect ( G_OBJECT(window), "delete_event", G_CALLBACK(gtk_main_quit), NULL);
 
 
